@@ -15,23 +15,32 @@ from tair.exceptions import (
     TimeoutError,
     WatchError,
 )
+from tair.taircpc import CpcUpdate2judResult
+from tair.tairgis import TairGisSearchMember, TairGisSearchRadius
 from tair.tairhash import ExhscanResult, FieldValueItem, ValueVersionItem
 from tair.tairroaring import TrScanResult
 from tair.tairsearch import ScandocidResult
 from tair.tairstring import ExcasResult, ExgetResult
+from tair.tairts import Aggregation, TairTsSkeyItem
 from tair.tairzset import TairZsetItem
 
 __all__ = [
-    "Tair",
-    "TairCluster",
-    "ExgetResult",
+    "Aggregation",
+    "CpcUpdate2judResult",
     "ExcasResult",
+    "ExgetResult",
     "ExhscanResult",
     "FieldValueItem",
-    "ValueVersionItem",
-    "TrScanResult",
     "ScandocidResult",
+    "Tair",
+    "TairCluster",
+    "TairGisSearchMember",
+    "TairGisSearchRadius",
+    "TairTsSkeyItem",
     "TairZsetItem",
+    "TrScanResult",
+    "ValueVersionItem",
+    # errors
     "AuthenticationError",
     "AuthenticationWrongNumberOfArgsError",
     "BusyLoadingError",
