@@ -1,7 +1,9 @@
-from typing import List, Optional
+from typing import Any, List, Optional
 
 from redis.asyncio.cluster import ClusterNode, RedisCluster
+from redis.exceptions import RedisClusterException
 
+from tair.asyncio.pipeline import ClusterPipeline
 from tair.commands import TairCommands, set_tair_response_callback
 
 
@@ -36,5 +38,13 @@ class TairCluster(RedisCluster, TairCommands):
         )
         set_tair_response_callback(self)
 
-    async def initialize(self):
-        await RedisCluster.initialize(self)
+    def pipeline(
+        self, transaction: Optional[Any] = None, shard_hint: Optional[Any] = None
+    ) -> ClusterPipeline:
+        if shard_hint:
+            raise RedisClusterException("shard_hint is deprecated in cluster mode")
+
+        if transaction:
+            raise RedisClusterException("transaction is deprecated in cluster mode")
+
+        return ClusterPipeline(self)
