@@ -4,6 +4,9 @@ from redis import Redis
 from redis.asyncio import Redis as AsyncRedis
 
 from tair.tairbloom import TairBloomCommands
+from tair.taircpc import CpcUpdate2judResult, TairCpcCommands
+from tair.tairdoc import TairDocCommands
+from tair.tairgis import TairGisCommands
 from tair.tairhash import (
     TairHashCommands,
     parse_exhgetall,
@@ -21,6 +24,7 @@ from tair.tairstring import (
     parse_exincrbyfloat,
     parse_exset,
 )
+from tair.tairts import TairTsCommands
 from tair.tairzset import TairZsetCommands, parse_tair_zset_items
 
 
@@ -31,6 +35,10 @@ class TairCommands(
     TairBloomCommands,
     TairRoaringCommands,
     TairSearchCommands,
+    TairGisCommands,
+    TairDocCommands,
+    TairTsCommands,
+    TairCpcCommands,
 ):
     pass
 
@@ -93,6 +101,37 @@ TAIR_RESPONSE_CALLBACKS = {
     "TFT.SEARCH": lambda resp: resp.decode(),
     "TFT.GETSUG": lambda resp: [i.decode() for i in resp],
     "TFT.GETALLSUGS": lambda resp: [i.decode() for i in resp],
+    # TairDoc
+    "JSON.SET": lambda resp: None if resp is None else resp == b"OK",
+    "JSON.TYPE": str_if_bytes,
+    # TairTs
+    "EXTS.P.CREATE": bool_ok,
+    "EXTS.S.CREATE": bool_ok,
+    "EXTS.S.ALTER": bool_ok,
+    "EXTS.S.ADD": bool_ok,
+    "EXTS.S.MADD": lambda resp: [bool_ok(i) for i in resp],
+    "EXTS.S.INCRBY": bool_ok,
+    "EXTS.S.MINCRBY": lambda resp: [bool_ok(i) for i in resp],
+    "EXTS.S.DEL": bool_ok,
+    "EXTS.S.RAW_MODIFY": bool_ok,
+    "EXTS.S.RAW_MMODIFY": lambda resp: [bool_ok(i) for i in resp],
+    "EXTS.S.RAW_INCRBY": bool_ok,
+    "EXTS.S.RAW_MINCRBY": lambda resp: [bool_ok(i) for i in resp],
+    # TairCpc
+    "CPC.UPDATE": bool_ok,
+    "CPC.ESTIMATE": lambda resp: float(resp.decode()),
+    "CPC.UPDATE2EST": lambda resp: float(resp.decode()),
+    "CPC.UPDATE2JUD": lambda resp: CpcUpdate2judResult(
+        float(resp[0].decode()), float(resp[1].decode())
+    ),
+    "CPC.ARRAY.UPDATE": bool_ok,
+    "CPC.ARRAY.ESTIMATE": lambda resp: float(resp.decode()),
+    "CPC.ARRAY.ESTIMATE.RANGE": lambda resp: [float(i.decode()) for i in resp],
+    "CPC.ARRAY.ESTIMATE.RANGE.MERGE": lambda resp: float(resp.decode()),
+    "CPC.ARRAY.UPDATE2EST": lambda resp: float(resp.decode()),
+    "CPC.ARRAY.UPDATE2JUD": lambda resp: CpcUpdate2judResult(
+        float(resp[0].decode()), float(resp[1].decode())
+    ),
 }
 
 
